@@ -35,8 +35,8 @@ def _f_expl_2_heun_euler_adptv(x0, Y0, dx, *args, dYdx=None, econ=0.0324, eps=0.
 
     Returns
     -------
-    Y1 : Field or False
-        New value of Y
+    dY : Field
+        Delta of variable to be integrated
         False if step size too large
 
     Butcher tableau
@@ -59,9 +59,9 @@ def _f_expl_2_heun_euler_adptv(x0, Y0, dx, *args, dYdx=None, econ=0.0324, eps=0.
     # Integration successful
     if emax <= 1.:
         # Suggest new stepsize
-        dxnew = safety*dx*emax**pgrow if econ > emax else 5.*dx
+        dxnew = safety*dx*emax**pgrow if econ < emax else 5.*dx
         x0.suggest(dxnew)
-        return Y0 + dx*(b0*k0 + b1*k1)
+        return dx*(b0*k0 + b1*k1)
     else:
         # Suggest new stepsize
         dxnew = np.maximum(safety*dx*emax**pshrink, 0.1*dx)
